Client class

A client which connects to a Spine-based backend, posts commands, sends queries, and creates and managed subscriptions on behalf of a certain user.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelAllSubscriptions() → void
Cancels all the subscriptions created by this client.
command<M extends GeneratedMessage>(M commandMessage) → CommandRequest<M>
Constructs a request to post a command to the server.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
select<M extends GeneratedMessage>() → QueryRequest<M>
Constructs a request to send a query to the server.
subscribeTo<M extends GeneratedMessage>() → StateSubscriptionRequest<M>
Constructs a request to create an entity state subscription.
subscribeToEvents<M extends GeneratedMessage>() → EventSubscriptionRequest<M>
Constructs a request to create an event subscription.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited