Endpoints class

URL paths to which the client should send requests.

Constructors

Endpoints({UrlPath query = 'query', UrlPath command = 'command', SubscriptionEndpoints? subscription})

Properties

command → String
final
hashCode → int
The hash code for this object.
no setterinherited
query → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription → SubscriptionEndpoints
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited