QueryRequest<M extends GeneratedMessage> class

A request to query the server for data.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fields(List<String> fieldPaths) → QueryRequest<M>
Specifies the fields to include in the query result.
limit(int count) → QueryRequest<M>
Adds a limit to the number of returned entity states.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orderBy(String column, [OrderBy_Direction direction = OrderBy_Direction.ASCENDING]) → QueryRequest<M>
Adds ordering to this query.
post() → Stream<M>
Asynchronously sends this request to the server.
toString() → String
A string representation of this object.
inherited
where(FilterOrComposite filter) → QueryRequest<M>
Adds field filters for the query results.
whereIds(Iterable<Object> ids) → QueryRequest<M>
Adds IDs to the query.

Operators

operator ==(Object other) → bool
The equality operator.
inherited