SubscriptionEndpoints class

URL paths to which the client should send requests regarding entity and event subscriptions.

See Endpoints.

Constructors

SubscriptionEndpoints({UrlPath create = 'subscription/create', UrlPath keepUp = 'subscription/keep-up', UrlPath cancel = 'subscription/cancel'})

Properties

cancel → String
final
create → String
final
hashCode → int
The hash code for this object.
no setterinherited
keepUp → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited