Service class

Inheritance
  • Object
  • GeneratedMessage
  • Service

Constructors

Service({String? name, String? title, Iterable<Api>? apis, Iterable<Type>? types, Iterable<Enum>? enums, Documentation? documentation, Backend? backend, Http? http, Quota? quota, Authentication? authentication, Context? context, Usage? usage, Iterable<Endpoint>? endpoints, UInt32Value? configVersion, Control? control, String? producerProjectId, Iterable<LogDescriptor>? logs, Iterable<MetricDescriptor>? metrics, Iterable<MonitoredResourceDescriptor>? monitoredResources, Billing? billing, Logging? logging, Monitoring? monitoring, SystemParameters? systemParameters, String? id, SourceInfo? sourceInfo})
factory
Service.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
Service.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

apis → List<Api>
no setter
authentication ↔ Authentication
getter/setter pair
backend ↔ Backend
getter/setter pair
billing ↔ Billing
getter/setter pair
configVersion ↔ UInt32Value
getter/setter pair
context ↔ Context
getter/setter pair
control ↔ Control
getter/setter pair
documentation ↔ Documentation
getter/setter pair
endpoints → List<Endpoint>
no setter
enums → List<Enum>
no setter
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
http ↔ Http
getter/setter pair
id ↔ String
getter/setter pair
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
logging ↔ Logging
getter/setter pair
logs → List<LogDescriptor>
no setter
metrics → List<MetricDescriptor>
no setter
monitoredResources → List<MonitoredResourceDescriptor>
no setter
monitoring ↔ Monitoring
getter/setter pair
name ↔ String
getter/setter pair
producerProjectId ↔ String
getter/setter pair
quota ↔ Quota
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceInfo ↔ SourceInfo
getter/setter pair
systemParameters ↔ SystemParameters
getter/setter pair
title ↔ String
getter/setter pair
types → List<Type>
no setter
unknownFields → UnknownFieldSet
no setterinherited
usage ↔ Usage
getter/setter pair

Methods

$_ensure<T>(int index) → T
For generated code only.
inherited
$_get<T>(int index, T defaultValue) → T
For generated code only.
inherited
$_getB(int index, bool defaultValue) → bool
For generated code only.
inherited
$_getBF(int index) → bool
For generated code only.
inherited
$_getI(int index, int defaultValue) → int
For generated code only.
inherited
$_getI64(int index) → Int64
For generated code only.
inherited
$_getIZ(int index) → int
For generated code only.
inherited
$_getList<T>(int index) → List<T>
For generated code only.
inherited
$_getMap<K, V>(int index) → Map<K, V>
For generated code only.
inherited
$_getN<T>(int index) → T
For generated code only.
inherited
$_getS(int index, String defaultValue) → String
For generated code only.
inherited
$_getSZ(int index) → String
For generated code only.
inherited
$_has(int index) → bool
For generated code only.
inherited
$_setBool(int index, bool value) → void
For generated code only.
inherited
$_setBytes(int index, List<int> value) → void
For generated code only.
inherited
$_setDouble(int index, double value) → void
For generated code only.
inherited
$_setFloat(int index, double value) → void
For generated code only.
inherited
$_setInt64(int index, Int64 value) → void
For generated code only.
inherited
$_setSignedInt32(int index, int value) → void
For generated code only.
inherited
$_setString(int index, String value) → void
For generated code only.
inherited
$_setUnsignedInt32(int index, int value) → void
For generated code only.
inherited
$_whichOneof(int oneofIndex) → int
inherited
addExtension(Extension extension, dynamic value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAuthentication() → void
clearBackend() → void
clearBilling() → void
clearConfigVersion() → void
clearContext() → void
clearControl() → void
clearDocumentation() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearHttp() → void
clearId() → void
clearLogging() → void
clearMonitoring() → void
clearName() → void
clearProducerProjectId() → void
clearQuota() → void
clearSourceInfo() → void
clearSystemParameters() → void
clearTitle() → void
clearUsage() → void
clone() → Service
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(Service)) → Service
Apply updates to a copy of this message.
override
createEmptyInstance() → Service
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureAuthentication() → Authentication
ensureBackend() → Backend
ensureBilling() → Billing
ensureConfigVersion() → UInt32Value
ensureContext() → Context
ensureControl() → Control
ensureDocumentation() → Documentation
ensureHttp() → Http
ensureLogging() → Logging
ensureMonitoring() → Monitoring
ensureQuota() → Quota
ensureSourceInfo() → SourceInfo
ensureSystemParameters() → SystemParameters
ensureUsage() → Usage
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAuthentication() → bool
hasBackend() → bool
hasBilling() → bool
hasConfigVersion() → bool
hasContext() → bool
hasControl() → bool
hasDocumentation() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasHttp() → bool
hasId() → bool
hasLogging() → bool
hasMonitoring() → bool
hasName() → bool
hasProducerProjectId() → bool
hasQuota() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSourceInfo() → bool
hasSystemParameters() → bool
hasTitle() → bool
hasUsage() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → Service
createRepeated() → PbList<Service>
getDefault() → Service