createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
EntityDeleted createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
EntityDeleted createEmptyInstance() => create();