createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
EventDispatchedToReactor createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
EventDispatchedToReactor createEmptyInstance() => create();